==> klayout-0.17.1.tar.gz: klayout-0.17.1/src/layApplication.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_layApplication
#define HDR_layApplication

#include <QtGui/QApplication>

#include "rba.h"
#include "gsiObject.h"

namespace gtf
{
  class Recorder;
}

namespace lay
{

class MainWindow;

/**
 *  @brief The basic application object
 *
 *  This object encapsulates command line parsing, creation of the main window
 *  widget and the basic execution loop.
 */
class Application
  : public gsi::Object<Application>
{
public:
  /**
   *  @brief The application constructor 
   *
   *  @param argc The number of external command-line arguments passed.
   *  @param argv The external command-line arguments.
   */
  Application (int &argc, char *argv []);

  /**
   *  @brief Destructor
   */
  ~Application ();

  /**
   *  @brief The singleton instance
   */
  static Application *instance ();

  /**
   *  @brief Return the program's version 
   */
  std::string version () const;

  /**
   *  @brief Return the program's usage string 
   */
  std::string usage () const;

  /**
   *  @brief Return the main window's reference
   *
   *  If the application has not been initialized properly, this pointer is 0.
   */
  MainWindow *main_window () const
  {
    return mp_mw;
  }

  /**
   *  @brief Run the application
   *
   *  This method issues all the lower level methods required in order to perform the
   *  applications main code.
   */
  int run ();

  /**
   *  @brief Execute the GUI main loop
   */
  int exec ();

  /**
   *  @brief Process pending events
   */
  void process_events ();

  /**
   *  @brief Set a configuration parameter
   */
  void set_config (const std::string &name, const std::string &value);

  /**
   *  @brief Clear the configuration
   */
  void clear_config ();

  /**
   *  @brief Write configuration to a file
   *
   *  If the configuration file cannot be written, false
   *  is returned but no exception is thrown.
   */
  bool write_config (const std::string &config_file);

  /**
   *  @brief Read the configuration from a file
   *
   *  This method siletly does nothing, if the config file does not
   *  exist. If it does and an error occured, the error message is printed
   *  on stderr. In both cases, false is returned.
   */
  bool read_config (const std::string &config_file);

  /**
   *  @brief Get a configuration parameter
   */
  std::string get_config (const std::string &name) const;

  /**
   *  @brief Obtain a list of names of configuration parameters
   */
  std::vector<std::string> get_config_names () const;

  /**
   *  @brief Return a reference to the Ruby interpreter
   */
  RubyInterpreter &ruby_interpreter () 
  {
    return m_ruby_interpreter;
  }

  /**
   *  @brief Return true, if undo buffering is enabled
   */
  bool is_undo_enabled () const
  {
    return m_enable_undo;
  }

  /**
   *  @brief Return true, if the application is in editable mode
   */
  bool is_editable () const
  {
    return m_editable;
  }

  /**
   *  @brief Return true, if the application has a GUI
   */
  bool has_gui () const
  {
    return ! m_no_gui;
  }

  /**
   *  @brief Reset config to global configuration
   */
  void reset_config (); 

private:
  std::vector <std::string> m_files;
  std::string m_layer_props_file;
  std::string m_ruby_script;
  std::vector<std::string> m_ruby_modules;
  std::string m_gtf_replay;
  std::string m_config_file;
  std::string m_global_config_file;
  bool m_write_config_file;
  std::vector< std::pair<std::string, std::string> > m_variables;
  int m_gtf_replay_rate, m_gtf_replay_stop;
  bool m_same_view;
  bool m_sync_mode;
  bool m_no_gui;
  bool m_editable;
  bool m_editable_set;
  bool m_enable_undo;
  QApplication m_qapp;
  //  HINT: the ruby interpreter must come after QApplication, so it is created after and 
  //  destroyed before QApplication - this way all Qt objects in the ruby interpreter are
  //  released before QApplication is destroyed
  RubyInterpreter m_ruby_interpreter;
  MainWindow *mp_mw;
  gtf::Recorder *mp_recorder;
};

} // namespace lay

namespace gsi {
  template <> struct ClassTag<lay::Application> {
    typedef CantCopySemanticsTag copy_semantics;
    typedef CantDefaultCreateSemanticsTag create_semantics;
  };
}

#endif

==> klayout-0.19.3.tar.gz: klayout-0.19.3/src/layApplication.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_layApplication
#define HDR_layApplication

#include <QtGui/QApplication>

#include "rba.h"
#include "gsiObject.h"

namespace gtf
{
  class Recorder;
}

namespace lay
{

class MainWindow;

/**
 *  @brief The basic application object
 *
 *  This object encapsulates command line parsing, creation of the main window
 *  widget and the basic execution loop.
 */
class Application
  : public gsi::Object<Application>
{
public:
  /**
   *  @brief The application constructor 
   *
   *  @param argc The number of external command-line arguments passed.
   *  @param argv The external command-line arguments.
   */
  Application (int &argc, char *argv []);

  /**
   *  @brief Destructor
   */
  ~Application ();

  /**
   *  @brief The singleton instance
   */
  static Application *instance ();

  /**
   *  @brief Return the program's version 
   */
  std::string version () const;

  /**
   *  @brief Return the program's usage string 
   */
  std::string usage () const;

  /**
   *  @brief Return the main window's reference
   *
   *  If the application has not been initialized properly, this pointer is 0.
   */
  MainWindow *main_window () const
  {
    return mp_mw;
  }

  /**
   *  @brief Run the application
   *
   *  This method issues all the lower level methods required in order to perform the
   *  applications main code.
   */
  int run ();

  /**
   *  @brief Execute the GUI main loop
   */
  int exec ();

  /**
   *  @brief Process pending events
   */
  void process_events ();

  /**
   *  @brief Set a configuration parameter
   */
  void set_config (const std::string &name, const std::string &value);

  /**
   *  @brief Clear the configuration
   */
  void clear_config ();

  /**
   *  @brief Write configuration to a file
   *
   *  If the configuration file cannot be written, false
   *  is returned but no exception is thrown.
   */
  bool write_config (const std::string &config_file);

  /**
   *  @brief Read the configuration from a file
   *
   *  This method siletly does nothing, if the config file does not
   *  exist. If it does and an error occured, the error message is printed
   *  on stderr. In both cases, false is returned.
   */
  bool read_config (const std::string &config_file);

  /**
   *  @brief Get a configuration parameter
   */
  std::string get_config (const std::string &name) const;

  /**
   *  @brief Obtain a list of names of configuration parameters
   */
  std::vector<std::string> get_config_names () const;

  /**
   *  @brief Return a reference to the Ruby interpreter
   */
  RubyInterpreter &ruby_interpreter () 
  {
    return m_ruby_interpreter;
  }

  /**
   *  @brief Return true, if undo buffering is enabled
   */
  bool is_undo_enabled () const
  {
    return m_enable_undo;
  }

  /**
   *  @brief Return true, if the application is in editable mode
   */
  bool is_editable () const
  {
    return m_editable;
  }

  /**
   *  @brief Return true, if the application has a GUI
   */
  bool has_gui () const
  {
    return ! m_no_gui;
  }

  /**
   *  @brief Reset config to global configuration
   */
  void reset_config (); 

  /**
   *  @brief Obtain the installation path
   */
  const std::string &inst_path () const
  {
    return m_inst_path;
  }

private:
  enum file_type {
    layout_file,
    rdb_file
  };

  std::vector <std::pair<file_type, std::string> > m_files;
  std::string m_layer_props_file;
  std::string m_session_file;
  std::string m_ruby_script;
  std::vector<std::string> m_ruby_modules;
  std::string m_gtf_replay;
  std::string m_config_file;
  std::string m_global_config_file;
  std::string m_inst_path;
  bool m_write_config_file;
  std::vector< std::pair<std::string, std::string> > m_variables;
  int m_gtf_replay_rate, m_gtf_replay_stop;
  bool m_same_view;
  bool m_sync_mode;
  bool m_no_gui;
  bool m_editable;
  bool m_editable_set;
  bool m_enable_undo;
  QApplication m_qapp;
  //  HINT: the ruby interpreter must come after QApplication, so it is created after and 
  //  destroyed before QApplication - this way all Qt objects in the ruby interpreter are
  //  released before QApplication is destroyed
  RubyInterpreter m_ruby_interpreter;
  MainWindow *mp_mw;
  gtf::Recorder *mp_recorder;
};

} // namespace lay

namespace gsi {
  template <> struct ClassTag<lay::Application> {
    typedef CantCopySemanticsTag copy_semantics;
    typedef CantDefaultCreateSemanticsTag create_semantics;
  };
}

#endif
